Package: jose
Type: Package
Title: JavaScript Object Signing and Encryption
Version: 2.0.0
Authors@R: person("Jeroen", "Ooms", role = c("aut", "cre"), 
    email = "jeroenooms@gmail.com", comment = c(ORCID = "0000-0002-4035-0289"))
Description: Read and write JSON Web Keys (JWK, rfc7517), generate and verify JSON
    Web Signatures (JWS, rfc7515) and encode/decode JSON Web Tokens (JWT, rfc7519)
    <https://datatracker.ietf.org/wg/jose/documents/>. These standards provide 
    modern signing and encryption formats that are natively supported by browsers
    via the JavaScript WebCryptoAPI <https://www.w3.org/TR/webcrypto/#jose>, 
    and used by services like OAuth 2.0, LetsEncrypt, and Github Apps.
License: MIT + file LICENSE
URL: https://r-lib.r-universe.dev/jose
BugReports: https://github.com/r-lib/jose/issues
Depends: openssl (>= 1.2.1)
Imports: jsonlite
RoxygenNote: 7.3.3.9000
VignetteBuilder: knitr
Suggests: spelling, testthat, knitr, rmarkdown
Encoding: UTF-8
Language: en-US
NeedsCompilation: no
Packaged: 2026-04-21 21:15:42 UTC; jeroen
Author: Jeroen Ooms [aut, cre] (ORCID: <https://orcid.org/0000-0002-4035-0289>)
Maintainer: Jeroen Ooms <jeroenooms@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-22 06:40:03 UTC
Built: R 4.6.0; ; 2026-04-27 07:41:11 UTC; unix
